# maysics
本库用于科学计算和快速建模

maysics主要包括十二个模块：<br/>
1、algo 封装了几种算法，用于简易分析；<br/>
2、calc 封装了常见的算符算子、函数、积分方法，辅助数学运算；<br/>
3、equa 封装了部分方程求解方法；<br/>
4、explain 用于评估和解释模型；<br/>
5、graph 用于图论分析；<br/>
6、image 用于数字图像处理;<br/>
7、models 封装了几种常用的模型以便快速构建数理模型；<br/>
8、prep 用于数据预处理；<br/>
9、stats 用于统计分析；<br/>
10、time 用于处理时间数据；<br/>
11、trans 封装了常用的坐标转换及其他数学变换；<br/>
12、utils 是额外工具箱。<br/>


This package is used for scientific calculating and fast modeling

maysics includes twelve modules:<br/>
1. "algo" packages several algorithms for simple analysis;<br/>
2. "calc" packaes common operatoes, functions and integration method;<br/>
3. "equa" packages some equation solving operation;<br/>
4. "explain" is used for estimating and explaining models;<br/>
5. "graph" is used for graph theory analysis;<br/>
6. "image" is used for digital image process;<br/>
7. "models" packages several coommon models for fast modeling;<br/>
8. "prep" is used for data preproccessing;<br/>
9. "stats" is uesd for statistical analysis;<br/>
10. "time" is used for processing time data;<br/>
11. "trans" packages common coordinate transformations and other mathematical transformations;<br/>
12. "utils" is extra Utils.